==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_banner.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_banner.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("BNRLAN_1", "Banner deleted.");
define("BNRLAN_2", "Please confirm you wish to delete this banner - once deleted it cannot be retrieved");
define("BNRLAN_5", "Confirm Delete Banner");
define("BNRLAN_6", "Delete cancelled.");
define("BNRLAN_7", "Existing Banners");
define("BNRLAN_8", "Banner ID");
define("BNRLAN_9", "Client");
define("BNRLAN_10", "Clickthroughs");
define("BNRLAN_11", "Click %");
define("BNRLAN_12", "Impressions");
define("BNRLAN_13", "Impressions Left");
define("BNRLAN_15", "No banners yet.");
define("BNRLAN_16", "Unlimited");
define("BNRLAN_17", "None");
define("BNRLAN_21", "Ends");
define("BNRLAN_22", "Update Banner");
define("BNRLAN_23", "Add New Banner");
define("BNRLAN_24", "Campaign");
define("BNRLAN_25", "choose existing campaign");
define("BNRLAN_26", "enter new campaign");
define("BNRLAN_27", "Client");
define("BNRLAN_28", "choose existing client");
define("BNRLAN_29", "enter new client");
define("BNRLAN_30", "Client Login");
define("BNRLAN_31", "Client Password");
define("BNRLAN_32", "Banner Image");
define("BNRLAN_33", "Click URL");
define("BNRLAN_34", "Impressions Purchased");
define("BNRLAN_35", "unlimited");
define("BNRLAN_36", "Start Date");
define("BNRLAN_37", "End Date");
define("BNRLAN_38", "blank = no limit");
define("BNRLAN_39", "visibility class");
define("BNRLAN_40", "Update Banner");
define("BNRLAN_41", "Create New Banner");
define("BNRLAN_42", "Banner Rotation System");
define("BNRLAN_43", "Choose banner image");
define("BNRLAN_45", "Starts");
define("BNRLAN_46", "Code");
define("BNRLAN_58", "banner front page");
define("BNRLAN_59", "create new banner");
define("BNRLAN_60", "campaigns");
define("BNRLAN_61", "banner menu ");
define("BNRLAN_62", "banner options");
define("BNRLAN_63", "Banner Created");
define("BNRLAN_64", "Banner Updated");

define("BANNER_MENU_L1", "Advertisement");
define("BANNER_MENU_L2", "Banner menu configuration saved");
define("BANNER_MENU_L3", "Caption");
define("BANNER_MENU_L5", "Banner Configuration"); 
define("BANNER_MENU_L6", "choose campaigns to show in menu");
define("BANNER_MENU_L7", "available campaigns");
define("BANNER_MENU_L8", "selected campaigns");
define("BANNER_MENU_L9", "remove selection");
define("BANNER_MENU_L10", "Render type");
//define("BANNER_MENU_L12", "plain");
//define("BANNER_MENU_L13", "in captioned box");
define("BANNER_MENU_L18", "Update Menu Settings");
define("BANNER_MENU_L19", "number of banners to show:<br />this is only used when multiple campaigns are selected");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_banner.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_banner.php $
|     $Revision: 11678 $
|     $Id: lan_banner.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("BNRLAN_1", "Banner deleted.");
define("BNRLAN_2", "Please confirm you wish to delete this banner - once deleted it cannot be retrieved");
define("BNRLAN_5", "Confirm Delete Banner");
define("BNRLAN_6", "Delete cancelled.");
define("BNRLAN_7", "Existing Banners");
define("BNRLAN_8", "Banner ID");
define("BNRLAN_9", "Client");
define("BNRLAN_10", "Clickthroughs");
define("BNRLAN_11", "Click %");
define("BNRLAN_12", "Impressions");
define("BNRLAN_13", "Impressions Left");
define("BNRLAN_15", "No banners yet.");
define("BNRLAN_16", "Unlimited");
define("BNRLAN_17", "None");
define("BNRLAN_21", "Ends");
define("BNRLAN_22", "Update Banner");
define("BNRLAN_23", "Add New Banner");
define("BNRLAN_24", "Campaign");
define("BNRLAN_25", "choose existing campaign");
define("BNRLAN_26", "enter new campaign");
define("BNRLAN_27", "Client");
define("BNRLAN_28", "choose existing client");
define("BNRLAN_29", "enter new client");
define("BNRLAN_30", "Client Login");
define("BNRLAN_31", "Client Password");
define("BNRLAN_32", "Banner Image");
define("BNRLAN_33", "Click URL");
define("BNRLAN_34", "Impressions Purchased");
define("BNRLAN_35", "unlimited");
define("BNRLAN_36", "Start Date");
define("BNRLAN_37", "End Date");
define("BNRLAN_38", "blank = no limit");
define("BNRLAN_39", "visibility class");
define("BNRLAN_40", "Update Banner");
define("BNRLAN_41", "Create New Banner");
define("BNRLAN_42", "Banner Rotation System");
define("BNRLAN_43", "Choose banner image");
define("BNRLAN_45", "Starts");
define("BNRLAN_46", "Code");
define("BNRLAN_58", "banner front page");
define("BNRLAN_59", "create new banner");
define("BNRLAN_60", "campaigns");
define("BNRLAN_61", "banner menu ");
define("BNRLAN_62", "banner options");
define("BNRLAN_63", "Banner Created");
define("BNRLAN_64", "Banner Updated");

define("BANNER_MENU_L1", "Advertisement");
define("BANNER_MENU_L2", "Banner menu configuration saved");
define("BANNER_MENU_L3", "Caption");
define("BANNER_MENU_L5", "Banner Configuration"); 
define("BANNER_MENU_L6", "choose campaigns to show in menu");
define("BANNER_MENU_L7", "available campaigns");
define("BANNER_MENU_L8", "selected campaigns");
define("BANNER_MENU_L9", "remove selection");
define("BANNER_MENU_L10", "Render type");
//define("BANNER_MENU_L12", "plain");
//define("BANNER_MENU_L13", "in captioned box");
define("BANNER_MENU_L18", "Update Menu Settings");
define("BANNER_MENU_L19", "number of banners to show:<br />this is only used when multiple campaigns are selected");

?>
